pub struct SignedExecutionReceipt {
pub schema: String,
pub schema_version: u32,
pub payload: ExecutionReceiptPayload,
pub signature: ReceiptSignature,
}Expand description
A signed receipt. The signer key is intentionally not embedded here.
Fields
schema: Stringschema_version: u32payload: ExecutionReceiptPayloadsignature: ReceiptSignatureImplementations
Sourceimpl SignedExecutionReceipt
impl SignedExecutionReceipt
Sourcepub fn from_file(path: impl AsRef<Path>) -> Result<Self, String>
pub fn from_file(path: impl AsRef<Path>) -> Result<Self, String>
Parse a bounded regular-file receipt and reject unknown or future data.
Sourcepub fn to_pretty_json(&self) -> Result<String, String>
pub fn to_pretty_json(&self) -> Result<String, String>
Serialize as indented JSON.
Sourcepub fn verify_signature(&self, key: &ReceiptPublicKey) -> Result<(), String>
pub fn verify_signature(&self, key: &ReceiptPublicKey) -> Result<(), String>
Verify against one separately supplied public key.
Sourcepub fn verify_policy(&self, policy: &ReceiptTrustPolicy) -> Result<(), String>
pub fn verify_policy(&self, policy: &ReceiptTrustPolicy) -> Result<(), String>
Verify against a key selected through an explicit trust/revocation policy.
Sourcepub fn verify_plan(&self, plan: &ExecutionPlan) -> Result<(), String>
pub fn verify_plan(&self, plan: &ExecutionPlan) -> Result<(), String>
Require the signed payload to correspond exactly to a supplied plan.
Sourcepub fn verify_with_key(
&self,
key: &ReceiptPublicKey,
plan: Option<&ExecutionPlan>,
receipt_path: &Path,
output_root: Option<&Path>,
) -> Result<ReceiptVerificationReport, String>
pub fn verify_with_key( &self, key: &ReceiptPublicKey, plan: Option<&ExecutionPlan>, receipt_path: &Path, output_root: Option<&Path>, ) -> Result<ReceiptVerificationReport, String>
Authenticate with one public key, optionally bind a supplied plan, and verify every output below a portable root.
Sourcepub fn verify_with_key_at_stream_output(
&self,
key: &ReceiptPublicKey,
plan: Option<&ExecutionPlan>,
receipt_path: &Path,
output_root: Option<&Path>,
stream_output: Option<&Path>,
) -> Result<ReceiptVerificationReport, String>
pub fn verify_with_key_at_stream_output( &self, key: &ReceiptPublicKey, plan: Option<&ExecutionPlan>, receipt_path: &Path, output_root: Option<&Path>, stream_output: Option<&Path>, ) -> Result<ReceiptVerificationReport, String>
Authenticate with one public key and optionally map the - locator in a
v2 stream receipt to an exact file that captured stdout.
Sourcepub fn verify_with_policy(
&self,
policy: &ReceiptTrustPolicy,
plan: Option<&ExecutionPlan>,
receipt_path: &Path,
output_root: Option<&Path>,
) -> Result<ReceiptVerificationReport, String>
pub fn verify_with_policy( &self, policy: &ReceiptTrustPolicy, plan: Option<&ExecutionPlan>, receipt_path: &Path, output_root: Option<&Path>, ) -> Result<ReceiptVerificationReport, String>
Authenticate through a rotation/revocation policy, optionally bind a supplied plan, and verify every output below a portable root.
Sourcepub fn verify_with_policy_at_stream_output(
&self,
policy: &ReceiptTrustPolicy,
plan: Option<&ExecutionPlan>,
receipt_path: &Path,
output_root: Option<&Path>,
stream_output: Option<&Path>,
) -> Result<ReceiptVerificationReport, String>
pub fn verify_with_policy_at_stream_output( &self, policy: &ReceiptTrustPolicy, plan: Option<&ExecutionPlan>, receipt_path: &Path, output_root: Option<&Path>, stream_output: Option<&Path>, ) -> Result<ReceiptVerificationReport, String>
Authenticate through a trust policy and optionally map the - locator
in a v2 stream receipt to an exact file that captured stdout.